import threading

local = threading.local()

DEFAULT_HEADER_VALUE = "none"
LOG_LABEL_REQUEST_SETTING = 'LOG_LABEL_REQUEST_SETTING'
LOG_LABEL_LOGGER_NAME = 'LOG_LABEL_LOGGER_NAME'
MAX_REQUEST_RESPONSE_SIZE = 'MAX_REQUEST_RESPONSE_SIZE'
